@@ -15,7 +15,7 @@ class Fpm:
     self.forceBuild = ['--force'] if config.force_build else []
     self.packagePrefix = "o2-"
     self.targetDir = config.target_rpm_dir
-    self.skipDeps = ['openmp', 'VecGeom', 'O2-customization']  # as sometimes there's mismatch between "requires" deps and modulefile
+    self.skipDeps = ['openmp', 'VecGeom', 'O2-customization', 're2']  # as sometimes there's mismatch between "requires" deps and modulefile
 
     # Create output dir
     if not os.path.exists(self.targetDir):
@@ -28,20 +28,16 @@ class Fpm:
     self.runtimeDepsDict = parseYamlDict(os.path.join(config.work_dir, 'runtime.' + self.release_suffix + '.yaml'))
     self.develDepsDict = parseYamlDict(os.path.join(config.work_dir, 'devel.' + self.release_suffix + '.yaml'))
 
-    if config.tag_version:
-        self.release_suffix += '_' + config.release_tag.replace('/', '_')
-
   def run(self, name, version, deps, devel_deps, extra_deps, RPMS_GENERATED = []):
     """ Prepares arguments and executes fpm """
     fullVersion = version
-    version = version.replace('local', '', 1)
     # split version and revision
     version_split = version.split('-')
     # split in case of vX.Y.Z-R
     # don't split if e.g. latest-o2-dataflow
     if len(version_split) == 2:
         version = version_split[0]
-        iterationArg = ['--iteration', version_split[1].replace('local', '', 1) + '.' + self.release_suffix]
+        iterationArg = ['--iteration', version_split[1] + '.' + self.release_suffix]
     else:
         iterationArg = ['--iteration', self.release_suffix]
 
@@ -51,7 +47,7 @@ class Fpm:
     # is not replicated and the target dir consists of only
     # prefix + package name + dir
     package_dir = self.buildDir + "/" + name + "/" + fullVersion + "/"
-    subdirs = ['bin', 'lib', 'lib64', 'etc', 'include', 'bin-safe', 'libexec', 'WebDID', 'plugins', 'cmake', 'share']
+    subdirs = ['bin', 'lib', 'lib64', 'etc', 'include', 'bin-safe', 'libexec', 'WebDID', 'share', 'plugins']
     paths = []
     for subdir in subdirs:
         if os.path.exists(package_dir + subdir):
@@ -68,7 +64,7 @@ class Fpm:
                  % (name, version, list(deps.items()), extra_deps, list({**devel_deps, **self.convertDepsToDevel(deps)}.items())))
 
     # Handle extra_deps
-    extra_deps = [v for dep in extra_deps for v in ('--depends', dep.replace('local', '', 1))]
+    extra_deps = [v for dep in extra_deps for v in ('--depends', dep)]
 
     packageName = self.packagePrefix + name
     fpmCommand = ['fpm',
@@ -90,7 +86,7 @@ class Fpm:
       '--after-remove', os.path.join(config.work_dir, 'after_remove_template.sh')]
 
     if paths:
-        fpmCommand.extend(['--exclude=*/modulefiles', '--exclude=*/profile.d', '--exclude=*/info/dir', '--exclude=*/version'])
+        fpmCommand.extend(['--exclude=*/modulefiles', '--exclude=*/profile.d'])
         fpmCommand.extend(paths)
 
     develPackageName = packageName + '-devel'
@@ -160,7 +156,7 @@ class Fpm:
             countDashes = depVersion.count('-')
             if countDashes > 1:
                 depVersion = depVersion.replace('-', '_', countDashes - 1)
-            depsArg.extend(['--depends', self.packagePrefix + depName + ' >= ' + depVersion.replace('local', '', 1)])
+            depsArg.extend(['--depends', self.packagePrefix + depName + ' >= ' + depVersion])
         else:  # coming from system, get name from dict
           if depName not in self.runtimeDepsDict:
             logging.critical('Could not find system dependency: %s \nDoes it suppose to come from aliBuild?' % (depName))
